==> amor-0.4.tgz: amor-0.4/amor/amordialog.h <==
//---------------------------------------------------------------------------
//
// amordialog.h
//
// Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
//

#ifndef AMORDIALOG_H 
#define AMORDIALOG_H 

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif 

#include <qdialog.h>
#include <qlistbox.h>
#include <qlist.h>

//---------------------------------------------------------------------------
//
// AmorDialog provides a setup dialog.
//
class AmorDialog : public QDialog
{
    Q_OBJECT
public:
    AmorDialog();
    virtual ~AmorDialog();

signals:
    //-----------------------------------------------------------------------
    //
    // The configuration has changed in some way.
    //
    void changed();

    //-----------------------------------------------------------------------
    //
    // The animation offset has been changed.
    //
    void offsetChanged(int);

protected slots:
    void slotHighlighted(int);
    void slotOnTop(bool);
    void slotOffset(int);
    void slotOk();
    void slotCancel();

protected:
    void readConfig();
    void writeConfig();
    void readThemes();
    void addTheme(QString path, QString file);

protected:
    QListBox *mThemeListBox;
    QStrList mThemes;
    QString  mCurrTheme;
    bool     mOnTop;
    int      mOffset;
};

//---------------------------------------------------------------------------
//
// AmorListBoxItem implements a list box items for selection of themes
//
class AmorListBoxItem : public QListBoxItem
{
public:
    AmorListBoxItem(const char *s, const QPixmap p)
        : QListBoxItem(), mPixmap(p)
        { setText(s); }

protected:
    virtual void paint(QPainter *);
    virtual int height(const QListBox *) const;
    virtual int width(const QListBox *) const;
    virtual const QPixmap *pixmap() { return &mPixmap; }

private:
    QPixmap mPixmap;
};

#endif // AMORDIALOG_H

==> amor-0.5.tgz: amor-0.5/amor/amordialog.h <==
//---------------------------------------------------------------------------
//
// amordialog.h
//
// Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
//

#ifndef AMORDIALOG_H 
#define AMORDIALOG_H 

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif 

#include <qdialog.h>
#include <qlistbox.h>
#include <qlist.h>
#include <qmultilinedit.h>
#include "amorconfig.h"

//---------------------------------------------------------------------------
//
// AmorDialog provides a setup dialog.
//
class AmorDialog : public QDialog
{
    Q_OBJECT
public:
    AmorDialog();
    virtual ~AmorDialog();

signals:
    //-----------------------------------------------------------------------
    //
    // The configuration has changed in some way.
    //
    void changed();

    //-----------------------------------------------------------------------
    //
    // The animation offset has been changed.
    //
    void offsetChanged(int);

protected slots:
    void slotHighlighted(int);
    void slotOnTop(bool);
    void slotRandomTips(bool);
    void slotOffset(int);
    void slotOk();
    void slotCancel();

protected:
    void readThemes();
    void addTheme(QString path, QString file);

protected:
    QListBox *mThemeListBox;
    QMultiLineEdit *mAboutEdit;
    QStrList mThemes;
    QStrList mThemeAbout;
    AmorConfig mConfig;
};

//---------------------------------------------------------------------------
//
// AmorListBoxItem implements a list box items for selection of themes
//
class AmorListBoxItem : public QListBoxItem
{
public:
    AmorListBoxItem(const char *s, const QPixmap p)
        : QListBoxItem(), mPixmap(p)
        { setText(s); }

protected:
    virtual void paint(QPainter *);
    virtual int height(const QListBox *) const;
    virtual int width(const QListBox *) const;
    virtual const QPixmap *pixmap() { return &mPixmap; }

private:
    QPixmap mPixmap;
};

#endif // AMORDIALOG_H
